﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.1 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"
                        xminimum 600
                        yminimum 110             

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu
        
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:

    # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .965

        has hbox

        textbutton _("New Game") xminimum 150 yminimum 120 action Start()
        textbutton _("Load Game") xminimum 150 yminimum 120 action ShowMenu("load")
        textbutton _("Preferences") xminimum 150 yminimum 120 action ShowMenu("preferences")
#        textbutton _("Help") xminimum 150 yminimum 120 action Help()
        textbutton _("Quit") xminimum 150 yminimum 120 action Quit(confirm=False)

init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98
        
        has vbox

        textbutton _("Return") xminimum 220 yminimum 100 action Return()
        textbutton _("Preferences") xminimum 220 yminimum 100 action ShowMenu("preferences")
        textbutton _("Save Game") xminimum 220 yminimum 100 action ShowMenu("save")
        textbutton _("Load Game") xminimum 220 yminimum 100 action ShowMenu("load")
        textbutton _("Main Menu") xminimum 220 yminimum 100 action MainMenu()
#        textbutton _("Help") xminimum 220 yminimum 100 action Help()
        textbutton _("Quit") xminimum 220 yminimum 100 action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            xmaximum 1000
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True
                    yminimum 100
                    xminimum 300

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    $ file_name = FileSlotName(i, columns * rows)
                    $ file_time = FileTime(i, empty=_("Empty Slot."))
                    $ save_name = FileSaveName(i)

                    text "[file_name]. [file_time!t]\n[save_name!t]"

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)

    

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces
    
screen preferences:

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a one-wide grid.
    grid 1 1:
        style_group "prefs"
        xfill True
        xmaximum 700

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") xminimum 220 yminimum 100 action Preference("display", "window")
                textbutton _("Fullscreen") xminimum 220 yminimum 100 action Preference("display", "fullscreen")

init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") xminimum 220 yminimum 100 action yes_action
            textbutton _("No") xminimum 220 yminimum 100 action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 1.0
        yalign 1.0

#        textbutton _("Q.Save") action QuickSave()
#        textbutton _("Q.Load") action QuickLoad()
#        textbutton _("Save") action ShowMenu('save')
#        textbutton _("Skip") action Skip()
#        textbutton _("Auto") action Preference("auto-forward", "toggle")
#        textbutton _("Prefs") action ShowMenu('preferences')
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
    
##############################################################################
# GUI (Jason Special Screen)
#
# Screen that's used to display GUI containing variables, score, stats
# 


define yGUI = 25
define xGUI = 1141
define yspacingGUI = 33
define textsizeGUI = 20
define colorGUI = "#FFFFFF"

screen gui:

    text ("%s %u.%u.%u" % (dayText, day, month, year)) size textsizeGUI xpos xGUI ypos yGUI color colorGUI xalign 0.5 yalign 0.5 xanchor 0.5 yanchor 0.5

#define yContractDebug = 100
#define xContractDebug = 5
#define yspacingContractDebug = 33
#define textsizeContractDebug = 24
#define colorContractDebug = "#FFFF00"

#screen contractDebug:

#    text ("expectedFights: %u" % expectedFights) size textsizeContractDebug xpos xContractDebug ypos yContractDebug color colorContractDebug
#    text ("expectedRank: %u" % expectedRank) size textsizeContractDebug xpos xContractDebug ypos (yContractDebug+(yspacingContractDebug*1)) color colorContractDebug
#    text ("expectedTitle: %s" % expectedTitle) size textsizeContractDebug xpos xContractDebug ypos (yContractDebug+(yspacingContractDebug*2)) color colorContractDebug
#    text ("expectedPurse: %u" % expectedPurse) size textsizeContractDebug xpos xContractDebug ypos (yContractDebug+(yspacingContractDebug*3)) color colorContractDebug


define yCreatingFighters = 0.5
define xCreatingFighters = 0.5
define yspacingCreatingFighters = 33
define textsizeCreatingFighters = 24
define colorCreatingFighters = "#FFFF00"

screen creatingFighters:

    text ("Fighters Created: %u" % x) size textsizeCreatingFighters xpos xCreatingFighters ypos yCreatingFighters color colorCreatingFighters
    

define yCalculatingRankings = 0.5
define xCalculatingRankings = 0.5
define yspacingCalculatingRankings = 33
define textsizeCalculatingRankings = 24
define colorCalculatingRankings = "#FFFF00"

screen calculatingRankings:

    text ("Calculating Rankings: %u" % y) size textsizeCalculatingRankings xpos xCalculatingRankings ypos yCalculatingRankings color colorCalculatingRankings


define xMatchGUI = 640
define yMatchGUI = 90
define yspacingMatchGUI = 70
define textsizeMatchGUI = 28
define colorMatchGUI = "#000000"

screen matchGUI:

    text ("%s %u.%u.%u" % (dayText, day, month, year)) size 24 xpos xMatchGUI ypos 26 color colorMatchGUI xalign 0.5 xanchor 0.5
    text ("Match %u" % matchNum) size 24 xpos xMatchGUI ypos 56 color colorMatchGUI xalign 0.5 xanchor 0.5
    text ("Round: %u" % fightRound) size 24 xpos xMatchGUI ypos 86 color colorMatchGUI xalign 0.5 xanchor 0.5
    text ("Time: %u:%u" % (roundMins, roundSecs)) size 24 xpos xMatchGUI ypos 116 color colorMatchGUI xalign 0.5 xanchor 0.5
    
    text ("- Energy -") size textsizeMatchGUI xpos xMatchGUI ypos (yMatchGUI+(yspacingMatchGUI*2)) xanchor 0.5 color "#FFFF00"
    text ("- KO Condition -") size textsizeMatchGUI xpos xMatchGUI ypos (yMatchGUI+(yspacingMatchGUI*3)) xanchor 0.5 color "#FFFF00"
    text ("- Bruise Condition -") size textsizeMatchGUI xpos xMatchGUI ypos (yMatchGUI+(yspacingMatchGUI*4)) xanchor 0.5 color "#FFFF00"
    text ("- Cut Condition -") size textsizeMatchGUI xpos xMatchGUI ypos (yMatchGUI+(yspacingMatchGUI*5)) xanchor 0.5 color "#FFFF00"
    


define yMatchRed = 90
define xMatchRed = 480
define xAnchorMatchRed = 1.0
define yspacingMatchRed = 70
define textsizeMatchRed = 28
define colorMatchRed = "#FFFF00"

screen matchRed:

    text ("%s %s" % (boxerFirstName[redFighter[matchRunning]],boxerSurname[redFighter[matchRunning]])) size 36 xpos xMatchRed ypos yMatchRed xanchor xAnchorMatchRed color "#FF0000"
    text ("%s" % (redEnergyText)) size textsizeMatchRed xpos xMatchRed ypos (yMatchRed+(yspacingMatchRed*2)) xanchor xAnchorMatchRed color colorMatchRed
    text ("%s" % (redKoText)) size textsizeMatchRed xpos xMatchRed ypos (yMatchRed+(yspacingMatchRed*3)) xanchor xAnchorMatchRed color colorMatchRed
    text ("%s" % (redBruisingText)) size textsizeMatchRed xpos xMatchRed ypos (yMatchRed+(yspacingMatchRed*4)) xanchor xAnchorMatchRed color colorMatchRed
    text ("%s" % (redCutsText)) size textsizeMatchRed xpos xMatchRed ypos (yMatchRed+(yspacingMatchRed*5)) xanchor xAnchorMatchRed color colorMatchRed
    
define yMatchBlue = 90
define xMatchBlue = 800
define xAnchorMatchBlue = 0.0
define yspacingMatchBlue = 70
define textsizeMatchBlue = 28
define colorMatchBlue = "#FFFF00"

screen matchBlue:

    text ("%s %s" % (boxerFirstName[blueFighter[matchRunning]],boxerSurname[blueFighter[matchRunning]])) size 36 xpos xMatchBlue ypos yMatchBlue xanchor xAnchorMatchBlue color "#0000FF"
    text ("%s" % (blueEnergyText)) size textsizeMatchBlue xpos xMatchBlue ypos (yMatchBlue+(yspacingMatchBlue*2)) xanchor xAnchorMatchBlue color colorMatchBlue
    text ("%s" % (blueKoText)) size textsizeMatchBlue xpos xMatchBlue ypos (yMatchBlue+(yspacingMatchBlue*3)) xanchor xAnchorMatchBlue color colorMatchBlue
    text ("%s" % (blueBruisingText)) size textsizeMatchBlue xpos xMatchBlue ypos (yMatchBlue+(yspacingMatchBlue*4)) xanchor xAnchorMatchBlue color colorMatchBlue
    text ("%s" % (blueCutsText)) size textsizeMatchBlue xpos xMatchBlue ypos (yMatchBlue+(yspacingMatchBlue*5)) xanchor xAnchorMatchBlue color colorMatchBlue
    
#define yMatchScoring = 130
#define xMatchScoring = 640
#define xAnchorMatchScoring = 0.5
#define yspacingMatchScoring = 33
#define textsizeMatchScoring = 24
#define colorMatchScoring = "#FFFF00"

#screen matchScoring:

#    text ("%u - Jabs Thrown - %u" % (redJabsThrown, blueJabsThrown)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*2)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("%u - Jabs Landed - %u" % (redJabsLanded, blueJabsLanded)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*3)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("%u - Power Punches Thrown - %u" % (redPowerPunchesThrown, bluePowerPunchesThrown)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*4)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("%u - Power Punches Landed - %u" % (redPowerPunchesLanded, bluePowerPunchesLanded)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*5)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("%u - Ring Generalship - %u" % (redRingGeneralshipScore, blueRingGeneralshipScore)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*6)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("%u - Defence - %u" % (redDefenceScore, blueDefenceScore)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*7)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("(%u) %u - Judge 1 - %u (%u)" % (redTotalPointsJudge1, redTotalScoreJudge1, blueTotalScoreJudge1, blueTotalPointsJudge1)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*8)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("(%u) %u - Judge 2 - %u (%u)" % (redTotalPointsJudge2, redTotalScoreJudge2, blueTotalScoreJudge2, blueTotalPointsJudge2)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*9)) xanchor xAnchorMatchScoring color colorMatchScoring
#    text ("(%u) %u - Judge 3 - %u (%u)" % (redTotalPointsJudge3, redTotalScoreJudge3, blueTotalScoreJudge3, blueTotalPointsJudge3)) size textsizeMatchScoring xpos xMatchScoring ypos (yMatchScoring+(yspacingMatchScoring*10)) xanchor xAnchorMatchScoring color colorMatchScoring
    
    
#define yDebugInjury = 120
#define xDebugInjury = 10
#define xAnchorDebugInjury = 0.0
#define yspacingDebugInjury = 33
#define textsizeDebugInjury = 18
#define colorDebugInjury = "#FFFF00"

#screen debugInjury:

#    text ("Cuts: %.2f" % boxerCutCondition[rankingSlot[statsIndex]]) size textsizeDebugInjury xpos xDebugInjury ypos yDebugInjury xanchor xAnchorDebugInjury color colorDebugInjury
#    text ("Bruise: %.2f" % boxerBruiseCondition[rankingSlot[statsIndex]]) size textsizeDebugInjury xpos xDebugInjury ypos (yDebugInjury+(yspacingDebugInjury*1)) xanchor xAnchorDebugInjury color colorDebugInjury
#    text ("KO: %.2f" % boxerKOCondition[rankingSlot[statsIndex]]) size textsizeDebugInjury xpos xDebugInjury ypos (yDebugInjury+(yspacingDebugInjury*2)) xanchor xAnchorDebugInjury color colorDebugInjury
    
    
#define yDebugContract = 300
#define xDebugContract = 10
#define xAnchorDebugContract = 0.0
#define yspacingDebugContract = 33
#define textsizeDebugContract = 18
#define colorDebugContract = "#FFFF00"

#screen debugContract:

#    text ("Fights: %u/%u" % (boxerContractFights[rankingSlot[statsIndex]], boxerPromiseFights[rankingSlot[statsIndex]])) size textsizeDebugContract xpos xDebugContract ypos yDebugContract xanchor xAnchorDebugContract color colorDebugContract
#    text ("Purse: %u/%u" % (boxerContractPurse[rankingSlot[statsIndex]], boxerPromisePurse[rankingSlot[statsIndex]])) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*1)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("Rank: %u/%u" % (boxerHighestRank[rankingSlot[statsIndex]], boxerPromiseRank[rankingSlot[statsIndex]])) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*2)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("Title: %s/%s" % (boxerContractTitle[rankingSlot[statsIndex]], boxerPromiseTitleShot[rankingSlot[statsIndex]])) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*3)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("Expiring: %u" % boxerContractExpiring[rankingSlot[statsIndex]]) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*4)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("Expired: %u" % boxerContractExpired[rankingSlot[statsIndex]]) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*5)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("boxerPlayerStable: %u" % boxerPlayerStable[rankingSlot[statsIndex]]) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*6)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("boxerHappyWithPlayer: %u" % boxerHappyWithPlayer[rankingSlot[statsIndex]]) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*7)) xanchor xAnchorDebugContract color colorDebugContract
#    text ("boxersOnContract: %u" % boxersOnContract) size textsizeDebugContract xpos xDebugContract ypos (yDebugContract+(yspacingDebugContract*8)) xanchor xAnchorDebugContract color colorDebugContract
    
    
screen knockdownTimer:

    text ("%u" % knockdownCounter) size 48 xpos 640 ypos 360 xanchor 0.5 yanchor 0.5 color "#FF0000"
    
    
#define yDebugProcessTiming = 10
#define xDebugProcessTiming = 10
#define xAnchorDebugProcessTiming = 0.0
#define yspacingDebugProcessTiming = 22
#define textsizeDebugProcessTiming = 18
#define colorDebugProcessTiming = "#FFFF00"

#screen debugProcessTiming:

    text ("Start Time: %.4f" % startTime) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos yDebugProcessTiming xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Loop Start Time: %.4f" % loopStartTime) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*1)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Total Run Time: %.4f" % totalRunTime) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*2)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 1  : %.4f" % timeGate1) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*3)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 2  : %.4f" % timeGate2) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*4)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 3  : %.4f" % timeGate3) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*5)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 4  : %.4f" % timeGate4) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*6)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 5  : %.4f" % timeGate5) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*7)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 6  : %.4f" % timeGate6) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*8)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 7  : %.4f" % timeGate7) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*9)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 8  : %.4f" % timeGate8) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*10)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 9  : %.4f" % timeGate9) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*11)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 10: %.4f" % timeGate10) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*12)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 11: %.4f" % timeGate11) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*13)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Time Gate 12: %.4f" % timeGate12) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*14)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
#    text ("Total Loop Time: %.4f" % totalLoopTime) size textsizeDebugProcessTiming xpos xDebugProcessTiming ypos (yDebugProcessTiming+(yspacingDebugProcessTiming*18)) xanchor xAnchorDebugProcessTiming color colorDebugProcessTiming
    
    
screen tipTextDisplay:

    text ("%s" % tipText) size 32 xpos 640 ypos 320 xanchor 0.5 yanchor 0.5 color "#000000"
    
    
screen commentaryDisplay:

    text ("%s" % commentaryText) size 32 xpos 640 ypos 630 xanchor 0.5 yanchor 0.5 xalign 0.5 yalign 0.5 color commentaryColour